@@ -400,7 +400,7 @@ def crossmatch_dual_psf():
         raise ValueError(f"file {psf_catalog} does not exist.")
 
     if not os.path.exists(save_file):
-        cmd  = 'stilts tmatch2 '
+        cmd  = f'java -jar {conf["path_to_stilts"]} tmatch2 '
         cmd += f'in1={dual_catalog} ifmt1=fits values1="RAJ2000 DEJ2000" '
         cmd += f'in2={psf_catalog} ifmt2=fits values2="RAJ2000 DEJ2000" '
         cmd += f'out={save_file} ofmt=fits '
@@ -729,7 +729,7 @@ if quality_path:
     suffix = ut.calibration_suffix(conf)
     extinction = conf['extinction_correction']
     save_file_quality_path = os.path.join(quality_path,
-                                         f'{field}_{suffix}_{extinction}.png')
+                                         f'{field}_{suffix}.png')
 
     plt.savefig(save_file_quality_path)
 
